<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>MX Repo Manager</source>
        <translation>MX Pakketbronbeheer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Selecteer de APT pakketbron die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Selecteer de snelste MX pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>zoeken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian pakketbronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Selecteer de snelste Debian pakketbron voor me</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Individuele bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Herstel originele APT bronnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Over deze applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Uw nieuwe selectie zal de volgende keer dat de bronnen geupdate worden effectief worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>Lijsten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Bronnen (aangevinkte bronnen zijn ingeschakeld)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="599"/>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <location filename="../mainwindow.cpp" line="644"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="677"/>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Could not change the repo.</source>
        <translation>Kon de pakketbron niet wijzigen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Please wait...</source>
        <translation>Even wachten aub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programma om de standaard APT pakketbron te kiezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Je hebt de MX Test Pakketbron geselecteerd. Het is niet aan te raden om deze ingeschakeld te laten of alle pakketten eruit te upgraden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Een veiliger optie is om pakketten individueel te installeren met MX Pakket Installeerder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Selecteer de APT pakketbron en bronnen die u wilt gebruiken:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kon de snelste pakketbron niet ontdekken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Kan niet achterhalen of deze app op antiX of MX draait</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="653"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX-versie niet gedetecteerd of buiten bereik:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Could not download original APT files.</source>
        <translation>Kon de originele APT bestanden niet downloaden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="677"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Kan het gedownloade bestand niet uitpakken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Enabling AHS</source>
        <translation>AHS inschakelen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Gebruikt u AHS (Advanced Hardware Stack) pakketbron?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Originele APT bronnen zijn teruggezet naar de release status. Bronbestanden die door de gebruiker zijn toegevoegd in /etc/apt/sources.list.d/ zijn niet gewijzigd.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Er is een fout opgetreden bij het schrijven van bestand: %1. Controleer of u voldoende vrije ruimte op uw schijf heeft</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
</context>
</TS>
